@@ -1,22 +1,12 @@
 """State representation with all properties."""
 from dataclasses import dataclass
+from .area import Area
 
 
 @dataclass
-class State:
+class State(Area):
     id: str = None
     name: str = None
-    population: int = 0
-    cases: int = 0
-    deaths: int = 0
-    casesPerWeek: int = 0
-    deathsPerWeek: int = 0
-    recovered = 0
-    weekIncidence = 0
-    casesPer100k: float = 0.0
-    newCases: int = 0
-    newDeaths: int = 0
-    newRecovered: int = 0
     vaccinationTotal = None
     vaccinationFirst = None
     vaccinationFull = None
